@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.098_03';
+our $VERSION = '0.098_04';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -1688,7 +1688,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sat Jun 23 13:46:52 2018 GMT
+# on Wed Jun 27 15:31:14 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1754,7 +1754,7 @@ __PACKAGE__->status( add => 25276, iridium => '+', 'Iridium 60', '' );
 __PACKAGE__->status( add => 25285, iridium => 'S', 'Iridium 62', '' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
-__PACKAGE__->status( add => 25288, iridium => '+', 'Iridium 65', '' );
+__PACKAGE__->status( add => 25288, iridium => 'S', 'Iridium 65', '' );
 __PACKAGE__->status( add => 25289, iridium => 'S', 'Iridium 66', '' );
 __PACKAGE__->status( add => 25290, iridium => '-', 'Iridium 67', 'Tumbling' );
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
@@ -1790,8 +1790,8 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => '+', 'Iridium 98', '' );
 
 # Summary:
-# Operational [+]: 20
-#       Spare [S]: 16
+# Operational [+]: 19
+#       Spare [S]: 17
 #    Tumbling [-]: 38
 #     Decayed [D]: 23
 
